@@ -395,7 +395,7 @@ def show_file(request, eid):
 def get_checksum(request, eid, value):
     element = get_object_or_404(Element.reader_queryset(request), id=eid)
     value = getattr(element, value)
-    return HttpResponse('%s ?%s\n' % (value, element.filename), content_type='text/plain')
+    return HttpResponse('%s %s\n' % (value, element.filename), content_type='text/plain')
 
 
 def get_signature(request, eid, sid):
